@@ -7,6 +7,7 @@ require 'sentry/utils/custom_inspection'
 require "sentry/dsn"
 require "sentry/release_detector"
 require "sentry/transport/configuration"
+require "sentry/cron/configuration"
 require "sentry/linecache"
 require "sentry/interfaces/stacktrace_builder"
 
@@ -14,6 +15,8 @@ module Sentry
   class Configuration
     include CustomInspection
     include LoggingHelper
+    include ArgumentCheckingHelper
+
     # Directories to be recognized as part of your app. e.g. if you
     # have an `engines` dir at the root of your project, you may want
     # to set this to something like /(app|config|engines|lib)/
@@ -38,6 +41,13 @@ module Sentry
     # @return [Integer]
     attr_accessor :background_worker_threads
 
+    # The maximum queue size for the background worker.
+    # Jobs will be rejected above this limit.
+    #
+    # Default is {BackgroundWorker::DEFAULT_MAX_QUEUE}.
+    # @return [Integer]
+    attr_accessor :background_worker_max_queue
+
     # a proc/lambda that takes an array of stack traces
     # it'll be used to silence (reduce) backtrace of the exception
     #
@@ -140,6 +150,14 @@ module Sentry
     # @return [Boolean]
     attr_accessor :include_local_variables
 
+    # Whether to capture events and traces into Spotlight. Default is false.
+    # If you set this to true, Sentry will send events and traces to the local
+    # Sidecar proxy at http://localhost:8969/stream.
+    # If you want to use a different Sidecar proxy address, set this to String
+    # with the proxy URL.
+    # @return [Boolean, String]
+    attr_accessor :spotlight
+
     # @deprecated Use {#include_local_variables} instead.
     alias_method :capture_exception_frame_locals, :include_local_variables
 
@@ -179,7 +197,7 @@ module Sentry
     # Release tag to be passed with every event sent to Sentry.
     # We automatically try to set this to a git SHA or Capistrano release.
     # @return [String]
-    attr_accessor :release
+    attr_reader :release
 
     # The sampling factor to apply to events. A value of 0.0 will not send
     # any events, and a value of 1.0 will send 100% of events.
@@ -209,13 +227,17 @@ module Sentry
     # @return [String]
     attr_accessor :server_name
 
-    # Return a Transport::Configuration object for transport-related configurations.
-    # @return [Transport]
+    # Transport related configuration.
+    # @return [Transport::Configuration]
     attr_reader :transport
 
+    # Cron related configuration.
+    # @return [Cron::Configuration]
+    attr_reader :cron
+
     # Take a float between 0.0 and 1.0 as the sample rate for tracing events (transactions).
-    # @return [Float]
-    attr_accessor :traces_sample_rate
+    # @return [Float, nil]
+    attr_reader :traces_sample_rate
 
     # Take a Proc that controls the sample rate for every tracing event, e.g.
     # @example
@@ -241,6 +263,17 @@ module Sentry
     # @return [Boolean]
     attr_accessor :auto_session_tracking
 
+    # Whether to downsample transactions automatically because of backpressure.
+    # Starts a new monitor thread to check health of the SDK every 10 seconds.
+    # Default is false
+    # @return [Boolean]
+    attr_accessor :enable_backpressure_handling
+
+    # Allowlist of outgoing request targets to which sentry-trace and baggage headers are attached.
+    # Default is all (/.*/)
+    # @return [Array<String, Regexp>]
+    attr_accessor :trace_propagation_targets
+
     # The instrumenter to use, :sentry or :otel
     # @return [Symbol]
     attr_reader :instrumenter
@@ -251,10 +284,24 @@ module Sentry
     # @return [Float, nil]
     attr_reader :profiles_sample_rate
 
+    # Array of patches to apply.
+    # Default is {DEFAULT_PATCHES}
+    # @return [Array<Symbol>]
+    attr_accessor :enabled_patches
+
     # these are not config options
     # @!visibility private
     attr_reader :errors, :gem_specs
 
+    # These exceptions could enter Puma's `lowlevel_error_handler` callback and the SDK's Puma integration
+    # But they are mostly considered as noise and should be ignored by default
+    # Please see https://github.com/getsentry/sentry-ruby/pull/2026 for more information
+    PUMA_IGNORE_DEFAULT = [
+      'Puma::MiniSSL::SSLError',
+      'Puma::HttpParserError',
+      'Puma::HttpParserError501'
+    ].freeze
+
     # Most of these errors generate 4XX responses. In general, Sentry clients
     # only automatically report 5xx responses.
     IGNORE_DEFAULT = [
@@ -279,6 +326,10 @@ module Sentry
 
     INSTRUMENTERS = [:sentry, :otel]
 
+    PROPAGATION_TARGETS_MATCH_ALL = /.*/.freeze
+
+    DEFAULT_PATCHES = %i(redis puma http).freeze
+
     class << self
       # Post initialization callbacks are called at the end of initialization process
       # allowing extending the configuration of sentry-ruby by multiple extensions
@@ -296,6 +347,7 @@ module Sentry
       self.app_dirs_pattern = nil
       self.debug = false
       self.background_worker_threads = Concurrent.processor_count
+      self.background_worker_max_queue = BackgroundWorker::DEFAULT_MAX_QUEUE
       self.backtrace_cleanup_callback = nil
       self.max_breadcrumbs = BreadcrumbBuffer::DEFAULT_SIZE
       self.breadcrumbs_logger = []
@@ -304,7 +356,7 @@ module Sentry
       self.environment = environment_from_env
       self.enabled_environments = []
       self.exclude_loggers = []
-      self.excluded_exceptions = IGNORE_DEFAULT.dup
+      self.excluded_exceptions = IGNORE_DEFAULT + PUMA_IGNORE_DEFAULT
       self.inspect_exception_causes_for_exclusion = true
       self.linecache = ::Sentry::LineCache.new
       self.logger = ::Sentry::Logger.new(STDOUT)
@@ -317,19 +369,23 @@ module Sentry
       self.skip_rake_integration = false
       self.send_client_reports = true
       self.auto_session_tracking = true
+      self.enable_backpressure_handling = false
       self.trusted_proxies = []
       self.dsn = ENV['SENTRY_DSN']
+      self.spotlight = false
       self.server_name = server_name_from_env
       self.instrumenter = :sentry
+      self.trace_propagation_targets = [PROPAGATION_TARGETS_MATCH_ALL]
+      self.enabled_patches = DEFAULT_PATCHES.dup
 
       self.before_send = nil
       self.before_send_transaction = nil
       self.rack_env_whitelist = RACK_ENV_WHITELIST_DEFAULT
-      self.traces_sample_rate = nil
       self.traces_sampler = nil
       self.enable_tracing = nil
 
       @transport = Transport::Configuration.new
+      @cron = Cron::Configuration.new
       @gem_specs = Hash[Gem::Specification.map { |spec| [spec.name, spec.version.to_s] }] if Gem::Specification.respond_to?(:map)
 
       run_post_initialization_callbacks
@@ -341,6 +397,12 @@ module Sentry
 
     alias server= dsn=
 
+    def release=(value)
+      check_argument_type!(value, String, NilClass)
+
+      @release = value
+    end
+
     def async=(value)
       check_callable!("async", value)
 
@@ -401,15 +463,25 @@ module Sentry
       @traces_sample_rate ||= 1.0 if enable_tracing
     end
 
+    def is_numeric_or_nil?(value)
+      value.is_a?(Numeric) || value.nil?
+    end
+
+    def traces_sample_rate=(traces_sample_rate)
+      raise ArgumentError, "traces_sample_rate must be a Numeric or nil" unless is_numeric_or_nil?(traces_sample_rate)
+      @traces_sample_rate = traces_sample_rate
+    end
+
     def profiles_sample_rate=(profiles_sample_rate)
-      log_info("Please make sure to include the 'stackprof' gem in your Gemfile to use Profiling with Sentry.") unless defined?(StackProf)
+      raise ArgumentError, "profiles_sample_rate must be a Numeric or nil" unless is_numeric_or_nil?(profiles_sample_rate)
+      log_warn("Please make sure to include the 'stackprof' gem in your Gemfile to use Profiling with Sentry.") unless defined?(StackProf)
       @profiles_sample_rate = profiles_sample_rate
     end
 
     def sending_allowed?
       @errors = []
 
-      valid? && capture_in_environment?
+      spotlight || (valid? && capture_in_environment?)
     end
 
     def sample_allowed?
@@ -435,19 +507,19 @@ module Sentry
       enabled_environments.empty? || enabled_environments.include?(environment)
     end
 
+    def valid_sample_rate?(sample_rate)
+      return false unless sample_rate.is_a?(Numeric)
+      sample_rate >= 0.0 && sample_rate <= 1.0
+    end
+
     def tracing_enabled?
-      valid_sampler = !!((@traces_sample_rate &&
-                          @traces_sample_rate >= 0.0 &&
-                          @traces_sample_rate <= 1.0) ||
-                         @traces_sampler)
+      valid_sampler = !!((valid_sample_rate?(@traces_sample_rate)) || @traces_sampler)
 
       (@enable_tracing != false) && valid_sampler && sending_allowed?
     end
 
     def profiling_enabled?
-      valid_sampler = !!(@profiles_sample_rate &&
-                         @profiles_sample_rate >= 0.0 &&
-                         @profiles_sample_rate <= 1.0)
+      valid_sampler = !!(valid_sample_rate?(@profiles_sample_rate))
 
       tracing_enabled? && valid_sampler && sending_allowed?
     end
@@ -477,7 +549,7 @@ module Sentry
     def detect_release
       return unless sending_allowed?
 
-      self.release ||= ReleaseDetector.detect_release(project_root: project_root, running_on_heroku: running_on_heroku?)
+      @release ||= ReleaseDetector.detect_release(project_root: project_root, running_on_heroku: running_on_heroku?)
 
       if running_on_heroku? && release.nil?
         log_warn(HEROKU_DYNO_METADATA_MESSAGE)
